# py-manga
## a library for getting information from mangaupdates.com!
[![Documentation Status](https://readthedocs.org/projects/py-manga/badge/?version=latest)](https://py-manga.readthedocs.io/en/latest/?badge=latest)
[![PyPi Package](https://img.shields.io/pypi/v/py-manga?color=dark-green)](https://pypi.org/project/py-manga/)

note: i am not affiliated with mangaupdates.com

mangaupdates, while offering a great source of information for your favorite manga, does not properly expose an api. it just returns the page html!
this is where py-manga comes in. using beautifulsoup, it parses all the information out of the html, making it way easier to work with.

**to see how the data is organized, see [the documentation](https://py-manga.readthedocs.io/en/latest)**

### Currently Supported
- Series information
- Searching
- Advanced/Genre Searching
- Latest Releases
